@@ -133,6 +133,7 @@ class RulesCollection(object):
 
     def __init__(self, ignore_rules=None, include_rules=None, configure_rules=None, include_experimental=False, mandatory_rules=None):
         self.rules = []
+        self.all_rules = []
 
         # Whether "experimental" rules should be added
         self.include_experimental = include_experimental
@@ -148,6 +149,7 @@ class RulesCollection(object):
 
     def register(self, rule):
         """Register rules"""
+        self.all_rules.append(rule)
         if self.is_rule_enabled(rule.id, rule.experimental):
             self.rules.append(rule)
             if rule.id in self.configure_rules:
@@ -162,6 +164,7 @@ class RulesCollection(object):
     def extend(self, more):
         """Extend rules"""
         for rule in more:
+            self.all_rules.append(rule)
             if self.is_rule_enabled(rule.id, rule.experimental):
                 self.rules.append(rule)
                 if rule.id in self.configure_rules:
