@@ -15,7 +15,7 @@ class AllowedValue(CloudFormationLintRule):
     shortdesc = 'Check if parameters have a valid value'
     description = 'Check if parameters have a valid value in case of an enumator. The Parameter\'s allowed values is based on the usages in property (Ref)'
     source_url = 'https://github.com/aws-cloudformation/cfn-python-lint/blob/master/docs/cfn-resource-specification.md#allowedvalue'
-    tags = ['resources', 'property', 'allowed value']
+    tags = ['parameters', 'resources', 'property', 'allowed value']
 
     def initialize(self, cfn):
         """Initialize the rule"""
