@@ -1,23 +1,11 @@
 """
-  Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-
-  Permission is hereby granted, free of charge, to any person obtaining a copy of this
-  software and associated documentation files (the "Software"), to deal in the Software
-  without restriction, including without limitation the rights to use, copy, modify,
-  merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
-  permit persons to whom the Software is furnished to do so.
-
-  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
-  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
-  PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
-  OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
-  SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+SPDX-License-Identifier: MIT-0
 """
 import sys
 import six
-from cfnlint import CloudFormationLintRule
-from cfnlint import RuleMatch
+from cfnlint.rules import CloudFormationLintRule
+from cfnlint.rules import RuleMatch
 import cfnlint.helpers
 
 
@@ -25,11 +13,19 @@ class ValuePrimitiveType(CloudFormationLintRule):
     """Check if Resource PrimitiveTypes are correct"""
     id = 'E3012'
     shortdesc = 'Check resource properties values'
-    description = 'Checks resource property values with Primitive Types for ' \
-                  'values that match those types.'
+    description = 'Checks resource property values with Primitive Types for values that match those types.'
     source_url = 'https://github.com/aws-cloudformation/cfn-python-lint/blob/master/docs/cfn-resource-specification.md#valueprimitivetype'
     tags = ['resources']
 
+    strict_exceptions = {
+        'AWS::CloudFormation::Stack': [
+            'Parameters'
+        ],
+        'AWS::Lambda::Function.Environment': [
+            'Variables'
+        ]
+    }
+
     def __init__(self):
         """Init"""
         super(ValuePrimitiveType, self).__init__()
@@ -53,27 +49,30 @@ class ValuePrimitiveType(CloudFormationLintRule):
         for property_spec in self.property_specs:
             self.resource_sub_property_types.append(property_spec)
 
-    def _value_check(self, value, path, item_type, extra_args):
+    def _value_check(self, value, path, item_type, strict_check, extra_args):
         """ Checks non strict """
         matches = []
-        if not self.config['strict']:
+        if not strict_check:
             try:
                 if item_type in ['String']:
                     str(value)
                 elif item_type in ['Boolean']:
                     if value not in ['True', 'true', 'False', 'false']:
-                        message = 'Property %s should be of type %s' % ('/'.join(map(str, path)), item_type)
+                        message = 'Property %s should be of type %s' % (
+                            '/'.join(map(str, path)), item_type)
                         matches.append(RuleMatch(path, message, **extra_args))
                 elif item_type in ['Integer', 'Long', 'Double']:
                     if isinstance(value, bool):
-                        message = 'Property %s should be of type %s' % ('/'.join(map(str, path)), item_type)
+                        message = 'Property %s should be of type %s' % (
+                            '/'.join(map(str, path)), item_type)
                         matches.append(RuleMatch(path, message, **extra_args))
                     elif item_type in ['Integer']:
                         int(value)
                     elif item_type in ['Long']:
                         # Some times python will strip the decimals when doing a conversion
                         if isinstance(value, float):
-                            message = 'Property %s should be of type %s' % ('/'.join(map(str, path)), item_type)
+                            message = 'Property %s should be of type %s' % (
+                                '/'.join(map(str, path)), item_type)
                             matches.append(RuleMatch(path, message, **extra_args))
                         if sys.version_info < (3,):
                             long(value)  # pylint: disable=undefined-variable
@@ -90,36 +89,37 @@ class ValuePrimitiveType(CloudFormationLintRule):
 
         return matches
 
-    def check_primitive_type(self, value, item_type, path):
+    def check_primitive_type(self, value, item_type, path, strict_check):
         """Chec item type"""
         matches = []
-
         if isinstance(value, dict) and item_type == 'Json':
             return matches
         if item_type in ['String']:
             if not isinstance(value, (six.string_types)):
                 extra_args = {'actual_type': type(value).__name__, 'expected_type': str.__name__}
-                matches.extend(self._value_check(value, path, item_type, extra_args))
+                matches.extend(self._value_check(value, path, item_type, strict_check, extra_args))
         elif item_type in ['Boolean']:
             if not isinstance(value, (bool)):
                 extra_args = {'actual_type': type(value).__name__, 'expected_type': bool.__name__}
-                matches.extend(self._value_check(value, path, item_type, extra_args))
+                matches.extend(self._value_check(value, path, item_type, strict_check, extra_args))
         elif item_type in ['Double']:
             if not isinstance(value, (float, int)):
-                extra_args = {'actual_type': type(value).__name__, 'expected_type': [float.__name__, int.__name__]}
-                matches.extend(self._value_check(value, path, item_type, extra_args))
+                extra_args = {'actual_type': type(value).__name__, 'expected_type': [
+                    float.__name__, int.__name__]}
+                matches.extend(self._value_check(value, path, item_type, strict_check, extra_args))
         elif item_type in ['Integer']:
             if not isinstance(value, (int)):
                 extra_args = {'actual_type': type(value).__name__, 'expected_type': int.__name__}
-                matches.extend(self._value_check(value, path, item_type, extra_args))
+                matches.extend(self._value_check(value, path, item_type, strict_check, extra_args))
         elif item_type in ['Long']:
             if sys.version_info < (3,):
                 integer_types = (int, long,)  # pylint: disable=undefined-variable
             else:
                 integer_types = (int,)
             if not isinstance(value, integer_types):
-                extra_args = {'actual_type': type(value).__name__, 'expected_type': ' or '.join([x.__name__ for x in integer_types])}
-                matches.extend(self._value_check(value, path, item_type, extra_args))
+                extra_args = {'actual_type': type(value).__name__, 'expected_type': ' or '.join([
+                    x.__name__ for x in integer_types])}
+                matches.extend(self._value_check(value, path, item_type, strict_check, extra_args))
         elif isinstance(value, list):
             message = 'Property should be of type %s at %s' % (item_type, '/'.join(map(str, path)))
             extra_args = {'actual_type': type(value).__name__, 'expected_type': list.__name__}
@@ -132,21 +132,23 @@ class ValuePrimitiveType(CloudFormationLintRule):
         matches = []
         primitive_type = kwargs.get('primitive_type', {})
         item_type = kwargs.get('item_type', {})
+        strict_check = kwargs.get('non_strict', self.config['strict'])
         if item_type in ['Map']:
             if isinstance(value, dict):
                 for map_key, map_value in value.items():
                     if not isinstance(map_value, dict):
-                        matches.extend(self.check_primitive_type(map_value, primitive_type, path + [map_key]))
+                        matches.extend(self.check_primitive_type(
+                            map_value, primitive_type, path + [map_key], strict_check))
         else:
             # some properties support primitive types and objects
             # skip in the case it could be an object and the value is a object
-            if item_type and isinstance(value, dict):
+            if (item_type or primitive_type) and isinstance(value, dict):
                 return matches
-            matches.extend(self.check_primitive_type(value, primitive_type, path))
+            matches.extend(self.check_primitive_type(value, primitive_type, path, strict_check))
 
         return matches
 
-    def check(self, cfn, properties, specs, path):
+    def check(self, cfn, properties, specs, spec_type, path):
         """Check itself"""
         matches = []
 
@@ -160,12 +162,17 @@ class ValuePrimitiveType(CloudFormationLintRule):
                 else:
                     item_type = None
                 if primitive_type:
+                    strict_check = self.config['strict']
+                    if spec_type in self.strict_exceptions:
+                        if prop in self.strict_exceptions[spec_type]:
+                            strict_check = False
                     matches.extend(
                         cfn.check_value(
                             properties, prop, path,
                             check_value=self.check_value,
                             primitive_type=primitive_type,
-                            item_type=item_type
+                            item_type=item_type,
+                            non_strict=strict_check,
                         )
                     )
 
@@ -177,7 +184,7 @@ class ValuePrimitiveType(CloudFormationLintRule):
 
         if self.property_specs.get(property_type, {}).get('Properties'):
             property_specs = self.property_specs.get(property_type, {}).get('Properties', {})
-            matches.extend(self.check(cfn, properties, property_specs, path))
+            matches.extend(self.check(cfn, properties, property_specs, property_type, path))
 
         return matches
 
@@ -185,6 +192,6 @@ class ValuePrimitiveType(CloudFormationLintRule):
         """Check CloudFormation Properties"""
         matches = []
         resource_specs = self.resource_specs.get(resource_type, {}).get('Properties', {})
-        matches.extend(self.check(cfn, properties, resource_specs, path))
+        matches.extend(self.check(cfn, properties, resource_specs, resource_type, path))
 
         return matches
