@@ -13,7 +13,7 @@ class LimitDescription(CloudFormationLintRule):
     shortdesc = 'Template description limit'
     description = 'Check if the size of the template description is less than the upper limit'
     source_url = 'https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/cloudformation-limits.html'
-    tags = ['limits']
+    tags = ['description', 'limits']
 
     def match(self, cfn):
         """Basic Matching"""
